ApplyScrubbing

Enum ApplyScrubbing 

pub enum ApplyScrubbing {
    Auto,
    Manual,
    Never,
}
Whether an attribute should be scrubbed.

Variants



Auto

The attribute will be stripped by default.



Manual

The attribute will only be stripped when addressed with a specific path selector, but generic selectors such as $string do not apply.



Never

The attribute cannot be stripped at all.