pub enum ReplacementName {
Static(&'static str),
Dynamic(fn(&str) -> String),
}Expand description
The name of the replacement of a deprecated attribute.
Variants
Static(&'static str)
The replacement attribute has a fixed name, i.e., doesn’t contain a placeholder.
Dynamic(fn(&str) -> String)
The replacement attribute contains a placeholder.
This means its name can’t be used “as-is”; a value has to be inserted into the placeholder. The contained function performs this insertion.