pub enum WriteBehavior {
CurrentName,
NewName(ReplacementName),
BothNames(ReplacementName),
}Expand description
Under which names an attribute should be saved.
Variants
CurrentName
Save the attribute under its current name.
This is the only choice for attributes that aren’t deprecated.
NewName(ReplacementName)
Save the attribute under its replacement name instead.
BothNames(ReplacementName)
Save the attribute under both its current name and its replacement name.