attribute_info_with_fragment

Function attribute_info_with_fragment 

pub fn attribute_info_with_fragment(
    key: &str,
) -> Option<(&'static AttributeInfo, Option<&str>)>
Returns information about an attribute, as defined in sentry-conventions.

If the matched attribute contains a placeholder (<key>), the second returned value is the part of the attribute key that was inserted for the placeholder.