pub fn canonical(key: &str) -> Option<&'static str>Expand description
Returns the “canonical” version of an attribute. This means:
- If the attribute is not deprecated, it is returned itself.
- If the attribute is deprecated and has a replacement, the replacement is returned.
- If the attribute is deprecated without a replacement,
Noneis returned. - If the attribute is not defined in
sentry-conventions,Noneis returned.